==> go-ld-prime-v0.0.1.tar.gz: go-ld-prime-v0.0.1/adl/rot13adl/rot13node_test.go <==
package rot13adl

import (
	"testing"

	. "github.com/warpfork/go-wish"

	"gitlab.dms3.io/ld/go-ld-prime"
	basicnode "gitlab.dms3.io/ld/go-ld-prime/node/basic"
)

func TestLogicalNodeRoundtrip(t *testing.T) {
	// Build high level node.
	nb := Prototype.Node.NewBuilder()
	err := nb.AssignString("abcd")
	Require(t, err, ShouldEqual, nil)
	n := nb.Build()
	// Inspect the high level node.
	s, err := n.AsString()
	Wish(t, err, ShouldEqual, nil)
	Wish(t, s, ShouldEqual, "abcd")
}

func TestNodeInternal(t *testing.T) {
	// Build high level node.
	nb := Prototype.Node.NewBuilder()
	err := nb.AssignString("abcd")
	Require(t, err, ShouldEqual, nil)
	n := nb.Build()
	// Poke its insides directly to see that the transformation occured.
	Wish(t, n.(*_R13String).synthesized, ShouldEqual, "abcd")
	Wish(t, n.(*_R13String).raw, ShouldEqual, "nopq")
}

func TestReify(t *testing.T) {
	t.Run("using unspecialized raw node", func(t *testing.T) {
		// Build substrate-shaped data using basicnode.
		sn := basicnode.NewString("nopq")
		// Reify it.
		synth, err := Reify(sn)
		// Inspect the resulting high level node.
		Require(t, err, ShouldEqual, nil)
		Wish(t, synth.Kind(), ShouldEqual, ld.Kind_String)
		s, err := synth.AsString()
		Wish(t, err, ShouldEqual, nil)
		Wish(t, s, ShouldEqual, "abcd")
	})
	t.Run("using substrate node", func(t *testing.T) {
		// Build substrate-shaped data, in the substrate type right from the start.
		snb := Prototype.SubstrateRoot.NewBuilder()
		snb.AssignString("nopq")
		sn := snb.Build()
		// Reify it.
		synth, err := Reify(sn)
		// Inspect the resulting high level node.
		Require(t, err, ShouldEqual, nil)
		Wish(t, synth.Kind(), ShouldEqual, ld.Kind_String)
		s, err := synth.AsString()
		Wish(t, err, ShouldEqual, nil)
		Wish(t, s, ShouldEqual, "abcd")
	})
}

func TestInspectingSubstrate(t *testing.T) {
	// Build high level node.
	nb := Prototype.Node.NewBuilder()
	err := nb.AssignString("abcd")
	Require(t, err, ShouldEqual, nil)
	n := nb.Build()
	// Ask it about its substrate, and inspect that.
	sn := n.(R13String).Substrate()
	// TODO: It's unfortunate this is only available as a concrete type cast: we should probably make a standard feature detection interface with `Substrate()`.
	//  Is it reasonable to make this part of a standard feature detection pattern,
	//   and make that interface reside in the main DMS3LD package?  Or in an `adl` package that contains such standard interfaces?
	ss, err := sn.AsString()
	Wish(t, err, ShouldEqual, nil)
	Wish(t, ss, ShouldEqual, "nopq")
}

==> go-ld-prime-v0.0.2.tar.gz: go-ld-prime-v0.0.2/adl/rot13adl/rot13node_test.go <==
package rot13adl

import (
	"testing"

	. "github.com/warpfork/go-wish"

	"gitlab.dms3.io/ld/go-ld-prime"
	basicnode "gitlab.dms3.io/ld/go-ld-prime/node/basic"
)

func TestLogicalNodeRoundtrip(t *testing.T) {
	// Build high level node.
	nb := Prototype.Node.NewBuilder()
	err := nb.AssignString("abcd")
	Require(t, err, ShouldEqual, nil)
	n := nb.Build()
	// Inspect the high level node.
	s, err := n.AsString()
	Wish(t, err, ShouldEqual, nil)
	Wish(t, s, ShouldEqual, "abcd")
}

func TestNodeInternal(t *testing.T) {
	// Build high level node.
	nb := Prototype.Node.NewBuilder()
	err := nb.AssignString("abcd")
	Require(t, err, ShouldEqual, nil)
	n := nb.Build()
	// Poke its insides directly to see that the transformation occured.
	Wish(t, n.(*_R13String).synthesized, ShouldEqual, "abcd")
	Wish(t, n.(*_R13String).raw, ShouldEqual, "nopq")
}

func TestReify(t *testing.T) {
	t.Run("using unspecialized raw node", func(t *testing.T) {
		// Build substrate-shaped data using basicnode.
		sn := basicnode.NewString("nopq")
		// Reify it.
		synth, err := Reify(sn)
		// Inspect the resulting high level node.
		Require(t, err, ShouldEqual, nil)
		Wish(t, synth.Kind(), ShouldEqual, ld.Kind_String)
		s, err := synth.AsString()
		Wish(t, err, ShouldEqual, nil)
		Wish(t, s, ShouldEqual, "abcd")
	})
	t.Run("using substrate node", func(t *testing.T) {
		// Build substrate-shaped data, in the substrate type right from the start.
		snb := Prototype.SubstrateRoot.NewBuilder()
		snb.AssignString("nopq")
		sn := snb.Build()
		// Reify it.
		synth, err := Reify(sn)
		// Inspect the resulting high level node.
		Require(t, err, ShouldEqual, nil)
		Wish(t, synth.Kind(), ShouldEqual, ld.Kind_String)
		s, err := synth.AsString()
		Wish(t, err, ShouldEqual, nil)
		Wish(t, s, ShouldEqual, "abcd")
	})
}

func TestInspectingSubstrate(t *testing.T) {
	// Build high level node.
	nb := Prototype.Node.NewBuilder()
	err := nb.AssignString("abcd")
	Require(t, err, ShouldEqual, nil)
	n := nb.Build()
	// Ask it about its substrate, and inspect that.
	sn := n.(R13String).Substrate()
	// TODO: It's unfortunate this is only available as a concrete type cast: we should probably make a standard feature detection interface with `Substrate()`.
	//  Is it reasonable to make this part of a standard feature detection pattern,
	//   and make that interface reside in the main LD package?  Or in an `adl` package that contains such standard interfaces?
	ss, err := sn.AsString()
	Wish(t, err, ShouldEqual, nil)
	Wish(t, ss, ShouldEqual, "nopq")
}
